/* Do file to run regressions in Ryan Banerjee and Aaron Mehrotra: "Disagreeing during deflations", JMCB (2020).
Created By Ryan Banerjee and Aaron Mehrotra
*/

clear all

cap log close

set more off

cd "XXXX"


use "XXXX\ban_mehr_jmcb_2020_data_for_journal.dta", clear

sysdir set PLUS "XXXX"
sysdir set PERSONAL "XXXX"

*generate variables for positive and negative forecasts and inflation gaps
gen oneyear_fc_pos=oneyear_fc if oneyear_fc>0 & !missing(oneyear_fc)
replace oneyear_fc_pos=0 if oneyear_fc<=0 & !missing(oneyear_fc)
gen oneyear_fc_neg=oneyear_fc if oneyear_fc<=0 & !missing(oneyear_fc)
replace oneyear_fc_neg=0 if oneyear_fc>0 & !missing(oneyear_fc)

gen inflgap_all_3_pos=inflgap_all_3 if inflgap_all_3>0 & !missing(inflgap_all_3)
replace inflgap_all_3_pos=0 if inflgap_all_3<=0 & !missing(inflgap_all_3)
gen inflgap_all_3_neg=inflgap_all_3 if inflgap_all_3<=0 & !missing(inflgap_all_3)
replace inflgap_all_3_neg=0 if inflgap_all_3>0 & !missing(inflgap_all_3)

reghdfe, compile

xtset countryid obs

*Table 1

*Column 1

reghdfe oneyear_iqr oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2  oneyear_fc_pos oneyear_fc_neg  deflation_new highinflation_new outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_table1, word replace label

*Column 2

reghdfe oneyear_iqr oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_table1, word append label

*Column 3

reghdfe oneyear_iqr oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_table1, word append label

*Column 4

reghdfe oneyear_idr oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_table1, word append label

*Column 5

reghdfe oneyear_idr oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_table1, word append label

*Table 2

/* create the actual inflation rate that corresponds to Consensus forecasts, using the price level */
tssmooth ma cpi_12M=cpiM, window (11 1)
gen infl_consensus=((cpi_12M/l12.cpi_12M)-1)*100

/* create the ex post forecast error using the previous measure and the mean forecast for the next calendar year */
gen fe_expost=infl_consensus-l12.nextyear_fc_mean if month==12
replace fe_expost=f.infl_consensus-l12.nextyear_fc_mean if month==11
replace fe_expost=f2.infl_consensus-l12.nextyear_fc_mean if month==10
replace fe_expost=f3.infl_consensus-l12.nextyear_fc_mean if month==9
replace fe_expost=f4.infl_consensus-l12.nextyear_fc_mean if month==8
replace fe_expost=f5.infl_consensus-l12.nextyear_fc_mean if month==7
replace fe_expost=f6.infl_consensus-l12.nextyear_fc_mean if month==6
replace fe_expost=f7.infl_consensus-l12.nextyear_fc_mean if month==5
replace fe_expost=f8.infl_consensus-l12.nextyear_fc_mean if month==4
replace fe_expost=f9.infl_consensus-l12.nextyear_fc_mean if month==3
replace fe_expost=f10.infl_consensus-l12.nextyear_fc_mean if month==2
replace fe_expost=f11.infl_consensus-l12.nextyear_fc_mean if month==1

/* create ex ante forecast forecast revision using the mean forecast for the next calendar year*/
gen frev_exante=l12.nextyear_fc_mean-l13.nextyear_fc_mean if month!=1

/* generate dummy variables */
gen otherinflation_new=1 if deflation_new==0 & highinflation_new==0
replace otherinflation_new=0 if deflation_new==1 & !missing(deflation_new)
replace otherinflation_new=0 if highinflation_new==1 & !missing(highinflation_new)

gen frev_exante_highinflation=frev_exante*highinflation_new
gen frev_exante_deflation=frev_exante*deflation_new
gen frev_exante_otherinflation=frev_exante*otherinflation_new

*Column 1
reghdfe fe_expost frev_exante if infl<10 & countryid!=37 & polrate_new<100, absorb(countryid month) vce(cluster countryid)
outreg2 frev_exante using ban_mehr_jmcb_table2, word replace label

*Column 2
reghdfe fe_expost frev_exante_highinflation frev_exante_deflation frev_exante_otherinflation deflation_new highinflation_new otherinflation_new if infl<10 & countryid!=37 & polrate_new<100, absorb(countryid month) vce(cluster countryid)
outreg2 frev_exante_highinflation frev_exante_deflation frev_exante_otherinflation using ban_mehr_jmcb_table2, word append label

*Table 3

*Column 1
reghdfe oneyear_pc25 oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_table3, word replace label

*Column 2
reghdfe oneyear_pc25 oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_table3, word append label

*Column 3
reghdfe oneyear_pc75 oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_table3, word append label

*Column 4
reghdfe oneyear_pc75 oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_table3, word append label

*Table 4

*Column 1
reghdfe oneyear_iqr oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & inflationtargeter_2==1 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_table4, word replace label

*Column 2
reghdfe oneyear_iqr oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & inflationtargeter_2!=1 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_table4, word append label

*Column 3
reghdfe oneyear_iqr oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & inflationtargeter_2==1 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_table4, word append label

*Column 4
reghdfe oneyear_iqr oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & inflationtargeter_2!=1 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_table4, word append label

*Column 5
reghdfe oneyear_iqr oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & zlb!=1 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_table4, word append label

*Column 6
reghdfe oneyear_iqr oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & zlb!=1 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_table4, word append label

*Online Appendix Table A4

*Column 1
reghdfe oneyear_iqr oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction if (infl<10 & polrate_new<100 & obs<237 & countryid!=37) | (infl<10 & polrate_new<100 & obs>252 & countryid!=37), absorb(countryid obs) vce(cluster countryid obs)
outreg2  oneyear_fc_pos oneyear_fc_neg  deflation_new highinflation_new outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_tablea4, word replace label

*Column 2
reghdfe oneyear_iqr oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if (infl<10 & polrate_new<100 & obs<237 & countryid!=37) | (infl<10 & polrate_new<100 & obs>252 & countryid!=37), absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_tablea4, word append label

*Column 3
reghdfe oneyear_iqr oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if (infl<10 & polrate_new<100 & obs<237 & countryid!=37) | (infl<10 & polrate_new<100 & obs>252 & countryid!=37), absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_tablea4, word append label

*Column 4
reghdfe oneyear_idr oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & obs<237 & countryid!=37 | infl<10 & polrate_new<100 & obs>252 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_tablea4, word append label

*Column 5
reghdfe oneyear_idr oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & obs<237 & countryid!=37 | infl<10 & polrate_new<100 & obs>252 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_tablea4, word append label

*Online Appendix Table A5

*Column 1

reghdfe oneyear_iqr oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_1s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_1s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_tablea5, word replace label

*Column 2
reghdfe oneyear_iqr oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_1s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_1s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_tablea5, word append label

*Column 3
reghdfe oneyear_iqr oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_shadow dpolrate_shadow_squared recession mpcontraction2 if infl<10 & polrate_shadow<100 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_shadow dpolrate_shadow_squared recession mpcontraction2 using ban_mehr_jmcb_tablea5, word append label

*Column 4
reghdfe oneyear_iqr oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_shadow dpolrate_shadow_squared recession mpcontraction2 if infl<10 & polrate_shadow<100 & countryid!=37, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_shadow dpolrate_shadow_squared recession mpcontraction2 using ban_mehr_jmcb_tablea5, word append label

*Online Appendix Table A6

*Column 1
reghdfe oneyear_pc25 oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & countryid!=37 & inflationtargeter_2==1, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_tablea6, word replace label

*Column 2
reghdfe oneyear_pc25 oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & countryid!=37 & inflationtargeter_2!=1, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_tablea6, word append label

*Column 3
reghdfe oneyear_pc25 oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & countryid!=37 & inflationtargeter_2==1, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_tablea6, word append label

*Column 4
reghdfe oneyear_pc25 oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & countryid!=37 & inflationtargeter_2!=1, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_tablea6, word append label

*Column 5
reghdfe oneyear_pc25 oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & countryid!=37 & zlb!=1, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_new highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_tablea6, word append label

*Column 6
reghdfe oneyear_pc25 oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction if infl<10 & polrate_new<100 & countryid!=37 & zlb!=1, absorb(countryid obs) vce(cluster countryid obs)
outreg2 oneyear_fc_pos oneyear_fc_neg deflation_pers highinflation_new  inflgap_all_3_pos inflgap_all_3_neg inflgap_all_3_squared outgap_2s_monthly abs_d_infl abs_d_infl_squared abs_d_lneer  polrate_new dpolrate_new_squared recession mpcontraction using ban_mehr_jmcb_tablea6, word append label


*Panel VARs, impulse responses shown in Graphs 3 and A1
*Requires the commands pvar and pvarirf, available from https://sites.google.com/a/hawaii.edu/inessalove/home/pvar


*shorten variable names for the estimation of pvar
gen lowertail_1y=oneyear_pc25
gen op2s=outgap_2s_monthly

*estimate the pvar used for Graph 3
pvar lowertail_1y oneyear_fc oneyear_gdp_iqr op2s infl polrate_new if infl<10 & polrate_new<100 & countryid!=37, lags(3) exog(jan feb mar apr jun jul aug sep oct nov dec)

*generate impulse responses, store results in a table. Note that to generate graphs as in the paper, need to invert the sign of the shock
pvarirf, mc(1000) oirf byopt(yrescale) level(90) step(40) impulse(lowertail_1y) table save(irfs_oneyear_25th)

*estimate the pvar used for Graph A1
pvar op2s infl polrate_new lowertail_1y oneyear_fc oneyear_gdp_iqr if infl<10 & polrate_new<100 & countryid!=37, lags(3) exog(jan feb mar apr jun jul aug sep oct nov dec)

*generate impulse responses, store results in a table. Note that to generate graphs as in the paper, need to invert the sign of the shock
pvarirf, mc(1000) oirf byopt(yrescale) level(90) step(40) impulse(lowertail_1y) table save(irfs_oneyear_25th_robust)

